==> deverhood-react-1.16.51.tgz: package/src/reducers/research.js <==
import { RESEARCH_API } from "../actions/actionType";
import Super from "./super";
import moment from "moment";
const defaultState = {
  list: [],
  data: {},
  form: {},
  forms: [],
  evaluations: [],
  evaluation: {},
  form_evaluations: [],
  manu_script: null,
  manages: [],
  activities: [],
  manage: {},
  activity: {},
  manage_activity: []
};

export default (state = defaultState, action) => {
  let reducer = new Super(state, action);
  switch (action.type) {
    case RESEARCH_API.SELF.GET.SUCCESS:
      return {
        ...reducer.get(),
        manage_activity: reducer.get().data.manageResearch.activities
      };
    case RESEARCH_API.SELF.ALL.SUCCESS:
      return reducer.list();
    case RESEARCH_API.CLEAR.ALL.SUCCESS:
      return reducer.clear();
    case RESEARCH_API.SELF.POST.SUCCESS:
      return reducer.post();
    case RESEARCH_API.SELF.PUT.SUCCESS:
      return reducer.put();
    case RESEARCH_API.SELF.DEL.SUCCESS:
      return reducer.delete();
    case RESEARCH_API.FORM.GET.SUCCESS:
      var moments = reducer.get("form").form.timelines
        ? reducer
            .get("form")
            .form.timelines.map(v => moment(v.start))
            .concat(reducer.get("form").form.timelines.map(v => moment(v.end)))
        : [];
      var maxC = moment.max(moments);
      var minC = moment.min(moments);
      var nextState = reducer.get("form");
      return {
        ...nextState,
        form: {
          ...nextState.form,
          associatedAppendix: nextState.form.associatedAppendix
            ? nextState.form.associatedAppendix.map(v => ({
                uid: v.file.id,
                name: v.file.alias,
                status: "done",
                response: { id: v.file.id },
                url: "/api/file/files/download/" + v.file.id
              }))
            : [],
          guaranteeAppendix: nextState.form.guaranteeAppendix
            ? nextState.form.guaranteeAppendix.map(v => ({
                uid: v.file.id,
                name: v.file.alias,
                status: "done",
                response: { id: v.file.id },
                url: "/api/file/files/download/" + v.file.id
              }))
            : [],
          recordFormAppendix: nextState.form.recordFormAppendix
            ? nextState.form.recordFormAppendix.map(v => ({
                uid: v.file.id,
                name: v.file.alias,
                status: "done",
                response: { id: v.file.id },
                url: "/api/file/files/download/" + v.file.id
              }))
            : [],
          informationAppendix: nextState.form.informationAppendix
            ? nextState.form.informationAppendix.map(v => ({
                uid: v.file.id,
                name: v.file.alias,
                status: "done",
                response: { id: v.file.id },
                url: "/api/file/files/download/" + v.file.id
              }))
            : [],
          informConsentAppendix: nextState.form.informConsentAppendix
            ? nextState.form.informConsentAppendix.map(v => ({
                uid: v.file.id,
                name: v.file.alias,
                status: "done",
                response: { id: v.file.id },
                url: "/api/file/files/download/" + v.file.id
              }))
            : [],
          researchCurriculumVitae: nextState.form.researchCurriculumVitae
            ? nextState.form.researchCurriculumVitae.map(v => ({
                uid: v.file.id,
                name: v.file.alias,
                status: "done",
                response: { id: v.file.id },
                url: "/api/file/files/download/" + v.file.id
              }))
            : []
        },
        minC,
        maxC
      };
    case RESEARCH_API.COMPARE.GET.SUCCESS:
      var moments = reducer.get("compare").form.timelines
        ? reducer
            .get("compare")
            .form.timelines.map(v => moment(v.start))
            .concat(
              reducer.get("compare").form.timelines.map(v => moment(v.end))
            )
        : [];
      var maxR = moment.max(moments);
      var minR = moment.min(moments);
      return { ...reducer.get("compare"), minR, maxR };
    case RESEARCH_API.FORM.PUT.SUCCESS:
      return reducer.put("form");
    case RESEARCH_API.MANU_SCRIPT.GET.SUCCESS:
      return reducer.get("manu_script");
    case RESEARCH_API.MANU_SCRIPT.POST.SUCCESS:
      return reducer.put("manu_script");
    case RESEARCH_API.MANU_SCRIPT.PUT.SUCCESS:
      return reducer.put("manu_script");
    case RESEARCH_API.COMMENT.POST.SUCCESS:
      return {
        ...state,
        data: {
          ...state.data,
          comments: state.data.comments
            ? [...state.data.comments, action.data]
            : [action.data]
        }
      };
    case RESEARCH_API.EVALUATION.GET.SUCCESS:
      return reducer.get("evaluation");
    case RESEARCH_API.EVALUATION.ALL.SUCCESS:
      return { ...state, evaluations: action.data };
    case RESEARCH_API.EVALUATION.POST.SUCCESS:
      return reducer.post("evaluations");
    case RESEARCH_API.FORM_EVALUATION.ALL.SUCCESS:
      return reducer.list("form_evaluations");
    case RESEARCH_API.FORM_EVALUATION.PUT.SUCCESS:
      return {
        ...state,
        evaluation: {
          ...state.evaluation,
          evaluations: state.evaluation.evaluations.map(v =>
            v.score.id === action.data.id
              ? { ...v, score: { ...action.data } }
              : { ...v }
          )
        }
      };
    case RESEARCH_API.MANAGE.ALL.SUCCESS:
      return reducer.list("manages");
    case RESEARCH_API.ACTIVITY.ALL.SUCCESS:
      return reducer.list("activities");
    case RESEARCH_API.MANAGE.POST.SUCCESS:
      return reducer.post("manages");
    case RESEARCH_API.ACTIVITY.POST.SUCCESS:
      return reducer.post("activities");
    case RESEARCH_API.MANAGE.PUT.SUCCESS:
      return reducer.put("manage", "manages");
    case RESEARCH_API.ACTIVITY.PUT.SUCCESS:
      return reducer.put("activity", "activities");
    case RESEARCH_API.MANAGE.DEL.SUCCESS:
      return reducer.delete("manages");
    case RESEARCH_API.ACTIVITY.DEL.SUCCESS:
      return reducer.delete("activities");
    case RESEARCH_API.MANAGE_ACTIVITY.PUT.SUCCESS:
      return {
        ...state,
        manage_activity: state.manage_activity.map(v =>
          v.id === action.data.id.activityId
            ? { ...v, researchActivity: { ...action.data } }
            : { ...v }
        )
      };
    default:
      return state;
  }
};

==> deverhood-react-1.16.59.tgz: package/src/reducers/research.js <==
import { RESEARCH_API } from "../actions/actionType";
import Super from "./super";
import moment from "moment";
const defaultState = {
  list: [],
  data: {},
  form: {},
  forms: [],
  evaluations: [],
  evaluation: {},
  form_evaluations: [],
  manu_script: null,
  manages: [],
  activities: [],
  manage: {},
  activity: {},
  manage_activity: []
};

export default (state = defaultState, action) => {
  let reducer = new Super(state, action);
  switch (action.type) {
    case RESEARCH_API.SELF.GET.SUCCESS:
      return {
        ...reducer.get(),
        manage_activity: reducer.get().data.manageResearch
          ? reducer.get().data.manageResearch.activities
          : []
      };
    case RESEARCH_API.SELF.ALL.SUCCESS:
      return reducer.list();
    case RESEARCH_API.CLEAR.ALL.SUCCESS:
      return reducer.clear();
    case RESEARCH_API.SELF.POST.SUCCESS:
      return reducer.post();
    case RESEARCH_API.SELF.PUT.SUCCESS:
      return reducer.put();
    case RESEARCH_API.SELF.DEL.SUCCESS:
      return reducer.delete();
    case RESEARCH_API.FORM.GET.SUCCESS:
      var moments = reducer.get("form").form.timelines
        ? reducer
            .get("form")
            .form.timelines.map(v => moment(v.start))
            .concat(reducer.get("form").form.timelines.map(v => moment(v.end)))
        : [];
      var maxC = moment.max(moments);
      var minC = moment.min(moments);
      var nextState = reducer.get("form");
      return {
        ...nextState,
        form: {
          ...nextState.form,
          associatedAppendix: nextState.form.associatedAppendix
            ? nextState.form.associatedAppendix.map(v => ({
                uid: v.file.id,
                name: v.file.alias,
                status: "done",
                response: { id: v.file.id },
                url: "/api/file/files/download/" + v.file.id
              }))
            : [],
          guaranteeAppendix: nextState.form.guaranteeAppendix
            ? nextState.form.guaranteeAppendix.map(v => ({
                uid: v.file.id,
                name: v.file.alias,
                status: "done",
                response: { id: v.file.id },
                url: "/api/file/files/download/" + v.file.id
              }))
            : [],
          recordFormAppendix: nextState.form.recordFormAppendix
            ? nextState.form.recordFormAppendix.map(v => ({
                uid: v.file.id,
                name: v.file.alias,
                status: "done",
                response: { id: v.file.id },
                url: "/api/file/files/download/" + v.file.id
              }))
            : [],
          informationAppendix: nextState.form.informationAppendix
            ? nextState.form.informationAppendix.map(v => ({
                uid: v.file.id,
                name: v.file.alias,
                status: "done",
                response: { id: v.file.id },
                url: "/api/file/files/download/" + v.file.id
              }))
            : [],
          informConsentAppendix: nextState.form.informConsentAppendix
            ? nextState.form.informConsentAppendix.map(v => ({
                uid: v.file.id,
                name: v.file.alias,
                status: "done",
                response: { id: v.file.id },
                url: "/api/file/files/download/" + v.file.id
              }))
            : [],
          researchCurriculumVitae: nextState.form.researchCurriculumVitae
            ? nextState.form.researchCurriculumVitae.map(v => ({
                uid: v.file.id,
                name: v.file.alias,
                status: "done",
                response: { id: v.file.id },
                url: "/api/file/files/download/" + v.file.id
              }))
            : []
        },
        minC,
        maxC
      };
    case RESEARCH_API.COMPARE.GET.SUCCESS:
      var moments = reducer.get("compare").form.timelines
        ? reducer
            .get("compare")
            .form.timelines.map(v => moment(v.start))
            .concat(
              reducer.get("compare").form.timelines.map(v => moment(v.end))
            )
        : [];
      var maxR = moment.max(moments);
      var minR = moment.min(moments);
      return { ...reducer.get("compare"), minR, maxR };
    case RESEARCH_API.FORM.PUT.SUCCESS:
      return reducer.put("form");
    case RESEARCH_API.MANU_SCRIPT.GET.SUCCESS:
      return reducer.get("manu_script");
    case RESEARCH_API.MANU_SCRIPT.POST.SUCCESS:
      return reducer.put("manu_script");
    case RESEARCH_API.MANU_SCRIPT.PUT.SUCCESS:
      return reducer.put("manu_script");
    case RESEARCH_API.COMMENT.POST.SUCCESS:
      return {
        ...state,
        data: {
          ...state.data,
          comments: state.data.comments
            ? [...state.data.comments, action.data]
            : [action.data]
        }
      };
    case RESEARCH_API.EVALUATION.GET.SUCCESS:
      return reducer.get("evaluation");
    case RESEARCH_API.EVALUATION.ALL.SUCCESS:
      return { ...state, evaluations: action.data };
    case RESEARCH_API.EVALUATION.POST.SUCCESS:
      return reducer.post("evaluations");
    case RESEARCH_API.FORM_EVALUATION.ALL.SUCCESS:
      return reducer.list("form_evaluations");
    case RESEARCH_API.FORM_EVALUATION.PUT.SUCCESS:
      return {
        ...state,
        evaluation: {
          ...state.evaluation,
          evaluations: state.evaluation.evaluations.map(v =>
            v.score.id === action.data.id
              ? { ...v, score: { ...action.data } }
              : { ...v }
          )
        }
      };
    case RESEARCH_API.MANAGE.ALL.SUCCESS:
      return reducer.list("manages");
    case RESEARCH_API.ACTIVITY.ALL.SUCCESS:
      return reducer.list("activities");
    case RESEARCH_API.MANAGE.POST.SUCCESS:
      return reducer.post("manages");
    case RESEARCH_API.ACTIVITY.POST.SUCCESS:
      return reducer.post("activities");
    case RESEARCH_API.MANAGE.PUT.SUCCESS:
      return reducer.put("manage", "manages");
    case RESEARCH_API.ACTIVITY.PUT.SUCCESS:
      return reducer.put("activity", "activities");
    case RESEARCH_API.MANAGE.DEL.SUCCESS:
      return reducer.delete("manages");
    case RESEARCH_API.ACTIVITY.DEL.SUCCESS:
      return reducer.delete("activities");
    case RESEARCH_API.MANAGE_ACTIVITY.PUT.SUCCESS:
      return {
        ...state,
        manage_activity: state.manage_activity.map(v =>
          v.id === action.data.id.activityId
            ? { ...v, researchActivity: { ...action.data } }
            : { ...v }
        )
      };
    default:
      return state;
  }
};
